<?php

/**
 * @file
 * Metatag integration for the agls module.
 *
 * @copyright Copyright(c) 2013 Previous Next Pty Ltd
 * @license GPL v2 http://www.fsf.org/licensing/licenses/gpl.html
 * @author Kim Pepper kim at previousnext dot com dot au
 * @author Nick Schuch nick at previousnext dot com dot au
 * @author Chris Skene chris at previousnext dot com dot au
 */

/**
 * Implements hook_metatag_config_default_alter().
 *
 * AGLS guidelines recommend several WCAG-relevant tag settings for both
 * DublinCore and AGLS. This function implements those settings on behalf
 * of the metatag_dc module.
 */
function agls_metatag_config_default_alter(array &$configs) {

  foreach ($configs as &$config) {
    switch ($config->instance) {
      case 'global':
        $config->config += array(
          'DCTERMS.title' => array('value' => '[current-page:title]'),
          'DCTERMS.type' => array('value' => 'Text'),
          'DCTERMS.format' => array('value' => 'text/html'),
        );
        break;

      case 'global:frontpage':
        $config->config += array(
          'DCTERMS.title' => array('value' => '[site:name]'),
          'DCTERMS.identifier' => array('value' => '[site:url]'),
        );
        break;

      case 'node':
        $config->config += array(
          'DCTERMS.title' => array('value' => '[node:title]'),
          'DCTERMS.description' => array('value' => '[node:body]'),
          'DCTERMS.date' => array('value' => '[node:created:custom:Y-m-d\TH:iP]'),
          'DCTERMS.identifier' => array('value' => '[site:url]node/[node:nid]'),
          'DCTERMS.language' => array('value' => '[node:language]'),
          'DCTERMS.creator' => array('value' => '[node:author]'),
          'DCTERMS.type' => array('value' => 'Text'),
        );
        break;

      case 'taxonomy_term':
        $config->config += array(
          'DCTERMS.title' => array('value' => '[term:name]'),
          'DCTERMS.identifier' => array('value' => '[site:url]taxonomy/term/[term:tid]'),
          'DCTERMS.description' => array('value' => '[term:description]'),
        );
        break;

      case 'user':
        $config->config += array(
          'DCTERMS.title' => array('value' => '[user:name]'),
          'DCTERMS.date' => array('value' => '[user:created:custom:Y-m-d\TH:iP]'),
          'DCTERMS.identifier' => array('value' => '[site:url]user/[user:uid]'),
          'DCTERMS.creator' => array('value' => '[user:name]'),
        );
        break;
    }
  }
}

/**
 * Implements hook_metatag_info().
 */
function agls_metatag_info() {

  // Define a AGLS group.
  $info['groups']['agls'] = array(
    'label' => t('AGLS'),
    'description' => t('The AGLS Metadata Standard provides a set of metadata
    properties and associated usage guidelines to improve the visibility,
    manageability and interoperability of online information and services.'),
    'form' => array(
      '#weight' => 95,
    ),
  );

  // AGLS specific terms.
  $info['tags']['AGLSTERMS.availability'] = array(
    'label' => t('AGLS: Availability'),
    'description' => t('How the resource can be obtained or accessed, or contact information (Mandatory for offline resources).'),
    'class' => 'DrupalTextMetaTag',
    'group' => 'agls',
  );
  $info['tags']['AGLSTERMS.function'] = array(
    'label' => t('AGLS: Function'),
    'description' => t('The business function to which the resource relates (Recommended if dcterms:subject is not used). AGIFT is the recommended thesaurus for Australian government agencies.'),
    'class' => 'DrupalTextMetaTag',
    'group' => 'agls',
  );
  $info['tags']['AGLSTERMS.mandate'] = array(
    'label' => t('AGLS: Mandate'),
    'description' => t('A specific legal instrument which requires or drives the creation or provision of the resource (Optional).'),
    'class' => 'DrupalTextMetaTag',
    'group' => 'agls',
  );

  return $info;
}
